@@ -1,6 +1,6 @@
 from getrails.duckduckgo.search import go_duck
 from getrails.google.search import go_gle
-from getrails.torch.search import go_onion
+from getrails.vidalia.search import go_onion
 from urllib import error
 
 def search (query):
